pub enum SendAuthType {
None,
Password {
password: String,
},
Emails {
emails: Vec<String>,
},
}Expand description
Type-safe authentication method for a Send, including the authentication data. This ensures that password and email authentication are mutually exclusive.
Variants
None
No authentication required
Password
Password-based authentication
Emails
Email-based OTP authentication
Implementations
Sourceimpl SendAuthType
impl SendAuthType