pub struct SendItem {
pub encryption_version: SendEncryptionType,
pub data: Cipher,
}Expand description
Item-based send content
Fields
encryption_version: SendEncryptionTypedata: CipherTrait Implementations
Sourceimpl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, SendItem> for SendItemView
impl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, SendItem> for SendItemView
Sourcefn encrypt_composite(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<SendItem, CryptoError>
fn encrypt_composite( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<SendItem, CryptoError>
⚠️ IMPORTANT NOTE ⚠️ Read more
Sourceimpl<UT> ConvertError<UT> for SendItem
impl<UT> ConvertError<UT> for SendItem
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Decryptable<KeySlotIds, SymmetricKeySlotId, SendItemView> for SendItem
impl Decryptable<KeySlotIds, SymmetricKeySlotId, SendItemView> for SendItem
Sourcefn decrypt(
&self,
ctx: &mut KeyStoreContext<'_, KeySlotIds>,
key: SymmetricKeySlotId,
) -> Result<SendItemView, CryptoError>
fn decrypt( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<SendItemView, CryptoError>
Decrypts
self into an Output under key. See the trait-level contract: the result must
contain no cipher text.Sourceimpl<'de> Deserialize<'de> for SendItem
impl<'de> Deserialize<'de> for SendItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for SendItem
impl<UT> FfiConverter<UT> for SendItem
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl FromWasmAbi for SendItemwhere
Self: DeserializeOwned,
impl FromWasmAbi for SendItemwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &SendItem
impl IntoWasmAbi for &SendItem
Sourceimpl IntoWasmAbi for SendItem
impl IntoWasmAbi for SendItem
Sourceimpl<UT> LiftReturn<UT> for SendItem
impl<UT> LiftReturn<UT> for SendItem
Sourcetype ReturnType = <SendItem as Lift<UT>>::FfiType
type ReturnType = <SendItem as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for SendItem
impl<UT> LowerError<UT> for SendItem
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for SendItem
impl<UT> LowerReturn<UT> for SendItem
Sourcetype ReturnType = <SendItem as Lower<UT>>::FfiType
type ReturnType = <SendItem as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for SendItem
impl OptionIntoWasmAbi for SendItem
Sourceimpl RefFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for SendItem
impl Tsify for SendItem
const DECL: &'static str = "/**\n * Item-based send content\n */\nexport interface SendItem {\n encryptionVersion: SendEncryptionType;\n data: Cipher;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for SendItemwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for SendItem
impl VectorIntoWasmAbi for SendItem
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for SendItem
impl WasmDescribeVector for SendItem